@@ -18,25 +18,30 @@ except MissingBackendError:
 
 
 def test_prefix():
-    db = SQLAlchemy('sqlite:///test.db')
-    auth = authcode.Auth(SECRET_KEY, db=db, roles=True, prefix='foobar')
-    assert auth.User
-    assert auth.Role
-    db.create_all()
-    db.session.add(auth.User(login=u'MeH', password='foobar'))
-    db.session.commit()
+    db = SQLAlchemy('sqlite:///:memory:')
+    auth1 = authcode.Auth(SECRET_KEY, db=db, roles=True, prefix='foobar')
 
-    assert auth.users_model_name == 'FoobarUser'
-    assert auth.roles_model_name == 'FoobarRole'
-    assert auth.views_prefix == 'foobar_'
-    assert auth.url_sign_in == '/foobar/sign-in/'
-    assert auth.url_sign_out == '/foobar/sign-out/'
-    assert auth.url_reset_password == '/foobar/reset-password/'
-    assert auth.url_change_password == '/foobar/change-password/'
+    assert auth1.users_model_name == 'FoobarUser'
+    assert auth1.roles_model_name == 'FoobarRole'
+    assert auth1.views_prefix == 'foobar_'
+    assert auth1.url_sign_in == '/foobar/sign-in/'
+    assert auth1.url_sign_out == '/foobar/sign-out/'
+    assert auth1.url_reset_password == '/foobar/reset-password/'
+    assert auth1.url_change_password == '/foobar/change-password/'
+
+    auth2 = authcode.Auth(SECRET_KEY, db=db, roles=True, prefix='meh')
+
+    assert auth2.users_model_name == 'MehUser'
+    assert auth2.roles_model_name == 'MehRole'
+    assert auth2.views_prefix == 'meh_'
+    assert auth2.url_sign_in == '/meh/sign-in/'
+    assert auth2.url_sign_out == '/meh/sign-out/'
+    assert auth2.url_reset_password == '/meh/reset-password/'
+    assert auth2.url_change_password == '/meh/change-password/'
 
 
 def test_automatic_case_insensitiveness():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
     User = auth.User
     db.create_all()
@@ -49,7 +54,7 @@ def test_automatic_case_insensitiveness():
 
 
 def test_disabled_case_insensitiveness():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, case_insensitive=False)
     User = auth.User
     db.create_all()
@@ -64,7 +69,7 @@ def test_disabled_case_insensitiveness():
 
 
 def test_automatic_password_hashing():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, hash='pbkdf2_sha512', rounds=10)
 
     User = auth.User
@@ -131,7 +136,7 @@ def test_legacy_reader():
 
 
 def test_sql_injection():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
     User = auth.User
     db.create_all()
@@ -151,7 +156,7 @@ def test_sql_injection():
 
 
 def test_authenticate_with_password():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -179,7 +184,7 @@ def test_authenticate_with_password():
 
 
 def test_user_has_none_password():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -208,7 +213,7 @@ def test_user_has_none_password():
 
 
 def test_user_has_empty_password():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, password_minlen=0)
 
     User = auth.User
@@ -240,7 +245,7 @@ def test_user_has_empty_password():
 
 
 def test_update_on_authenticate():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, hash='pbkdf2_sha512',
                          update_hash=True)
     User = auth.User
@@ -265,7 +270,7 @@ def test_update_on_authenticate():
 
 
 def test_disable_update_on_authenticate():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, hash='pbkdf2_sha512',
                          update_hash=False)
     User = auth.User
@@ -288,7 +293,7 @@ def test_disable_update_on_authenticate():
 
 def test_get_token():
     from time import time, sleep
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -311,7 +316,7 @@ def test_get_token():
 
 def test_authenticate_with_token():
     from time import time
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, token_life=3 * 60)
 
     User = auth.User
@@ -344,7 +349,7 @@ def test_authenticate_with_token():
 
 
 def test_get_uhmac():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -359,7 +364,7 @@ def test_get_uhmac():
 
 
 def test_login_logout():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -378,7 +383,7 @@ def test_login_logout():
 
 
 def test_login_repeated_logout():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -400,7 +405,7 @@ def test_login_repeated_logout():
 
 
 def test_clear_session_on_logout():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -425,7 +430,7 @@ def test_clear_session_on_logout():
 
 
 def test_dont_clear_session_on_logout():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, clear_session_on_logout=False)
 
     User = auth.User
@@ -450,7 +455,7 @@ def test_dont_clear_session_on_logout():
 
 
 def test_get_user():
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
 
     User = auth.User
@@ -500,7 +505,7 @@ def test_replace_hash_password_method():
                 return False
             return self.hash_password(secret) == hashed
 
-    db = SQLAlchemy('sqlite://')
+    db = SQLAlchemy('sqlite:///:memory:')
     auth = CustomAuth(SECRET_KEY, db=db)
     User = auth.User
     db.create_all()
